/*
 *
 *   MPGui - a Gui for MiniPad
 *   it helps you to develop java and c programs in the simpliest way possible
 *   providing the minimum set of functions needed and the shortest way to get them
 *   (like a big, clear and coloured button, a menu item and a keybord shortcut).
 *   It acts as a frontend for javac and gcc.
 *
 *   Require JDK 1.2
 *           
 *   Copyright (C) 1999  Andrea Gini
 *
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *   Send questions or suggestions to ginian@lib.disco.unimib.it
 *
 */
/**
   E' l'interfaccia grafica del programma.
   E' composta da una finestra con una toolbar e una menubar per accedere alle funzioni (a NORD), una JTextArea per editare il sorgente (in CENTRO) e un'altra JTextArea per vedere l'output del compilatore (a SUD). 
 */
import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.text.*;

public class MPGui extends JFrame
{
  private int HSize = 400;
  private int VSize = 500;
  private JTextArea _editor;
  private JTextArea _outPanel;
  
  private String[] _toolbarStructure =
  {
    MPAbstractAction.NEW,
    MPAbstractAction.OPEN,
    MPAbstractAction.SAVE,
    MPAbstractAction.COMPILE,
    MPAbstractAction.RUN,
    MPAbstractAction.STOP,
  };
  private String[] _fileMenuStructure =
  {
    MPAbstractAction.NEW,
    MPAbstractAction.OPEN,
    MPAbstractAction.SAVE,
    MPAbstractAction.SAVE_AS,
    MPAbstractAction.EXIT
  };  
  public MPGui(Action[] actions)
  {
    super();
    setSize(HSize,VSize);
    _editor=new JTextArea();
    _outPanel=new JTextArea(new OutPanelDocument());  // crea il pannello di ouput con l'apposito documento OutPanelDocument
    _outPanel.setEditable(false);
    
    JToolBar jtb = new JToolBar();
    JMenuBar jmb = new JMenuBar();
    JMenu fileMenu = new JMenu("File");
    Hashtable commands = new Hashtable();

    for (int i = 0; i < actions.length; i++)
    {
      Action a = actions[i];
      commands.put(a.getValue(Action.NAME), a);
    }    
    // crea la pulsantiera secondo il modello contenuto nel vettore _toolbarStructure
    for(int i=0;i<_toolbarStructure.length;i++)
    {
      Action a = (Action)commands.get(_toolbarStructure[i]);
      jtb.add(a);
    }
    // crea il menu secondo il modello contenuto nel vettore _fileMenuStructure
    for(int i=0;i<_fileMenuStructure.length;i++)
    {
      Action a = (Action)commands.get(_fileMenuStructure[i]);
      fileMenu.add(a);
    }

    //Associa al tasto di chiusura applicazione l'azione EXIT
    setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
    Action exAct = (Action)commands.get(MPAbstractAction.EXIT);
    addWindowListener(new MPGuiWindowAdapter(this,exAct));

    jmb.add(fileMenu);
    setJMenuBar(jmb);
    
    // crea uno splitpane contenente le due textarea
    JSplitPane split = new JSplitPane(JSplitPane.VERTICAL_SPLIT,new JScrollPane(_editor),new JScrollPane(_outPanel));
    split.setOneTouchExpandable(true);
    split.setDividerLocation(200);
    getContentPane().add(BorderLayout.NORTH,jtb);     
    getContentPane().add(BorderLayout.CENTER,split);
    
    split.setDividerLocation(VSize-100);
    
    setVisible(true);
  }
  /**
    restituisce un reference al frame corrente (la classe stessa).
    Tale reference e' indispensabile per aprire finestre modali (come il JFileChooser)
   */
  public JFrame getFrame()
  {
    return this;
  }
    /**
       Viene invocato all'atto della creazione di un nuovo documento.
       Il documento viene posto nella JTextArea apposita
       @roseuid 38A183FF0334
     */
    public void setDocument(MPDocument d)
    {
      _editor.setDocument(d);
    }
    public MPDocument getDocument()
    {
       Document doc = _editor.getDocument();
       if(doc instanceof MPDocument)
         return (MPDocument)doc;
       else
         return null;
    }
    
    /**
       Viene restituita la console.
     */
    public Console getConsole()
    {
      Document doc = _outPanel.getDocument();
      
      if(doc instanceof Console)
        return(Console)doc;
      else
        return null;
    }
    
  /**
   * WindowAdapter che permette di chiudere l'applicazione in maniera pulita
   * quando si chiude la finestra.
   */
  class MPGuiWindowAdapter extends WindowAdapter
  {
    private Component _source;
    private Action _exAct;
    
    public MPGuiWindowAdapter(Component source,Action exAct)
    {
      _source = source;
      _exAct = exAct;
    }
    public void windowClosing(WindowEvent e)
    {
      _exAct.actionPerformed(new ActionEvent(_source,AWTEvent.RESERVED_ID_MAX+1,MPAbstractAction.EXIT));
    }
  }
}
