/*
 *
 *   OutPanelDocument - an implementation of the Console Interface. 
 *   it helps you to develop java and c programs in the simpliest way possible
 *   providing the minimum set of functions needed and the shortest way to get them
 *   (like a big, clear and coloured button, a menu item and a keybord shortcut).
 *   It acts as a frontend for javac and gcc.
 *
 *   Require JDK 1.2
 *           
 *   Copyright (C) 1999  Andrea Gini
 *
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *   Send questions or suggestions to ginian@lib.disco.unimib.it
 *
 */

import java.io.*;
import javax.swing.*;
import javax.swing.text.*;

class OutPanelDocument extends PlainDocument implements Console
{
  public OutPanelDocument()
  {
    super();
  }
  public void bindOutput(Process p,String processName)
  {
    OutputGrabber outGrab = new OutputGrabber(p.getInputStream(),this);
    outGrab.start();
    OutputGrabber errGrab = new OutputGrabber(p.getErrorStream(),this);
    errGrab.start();
//      outPanel.setOutputStream(p.getOutputStream());
    WaitProcessEnd waiter = new WaitProcessEnd(p,this,processName);
    waiter.start();
  }
  class OutputGrabber extends Thread
  {
    BufferedInputStream in;
    private Document outPanel;

    public OutputGrabber(InputStream in,Document outPanel)
    {
      this.in = new BufferedInputStream(in);
      this.outPanel = outPanel;
      setDaemon(true);
    }
    public void run()
    {
      String s;
      byte b[] = new byte[1024];
      int len;
      try
      {
        while((len = in.read(b))>=0)
        {
          s = new String(b,0,len);
          outPanel.insertString(getLength(),s,(AttributeSet)null);
        }
      }
      catch(Exception e)
      {}
    } // public void run()
  } // class outputGrabber
  public class WaitProcessEnd extends Thread
  {
    private Process p;
    private Document outPanel;
    private String processName;
    private int err = 0;

    public WaitProcessEnd(Process p,Document outPanel,String processName)
    {
      this.p = p;
      this.outPanel = outPanel;
      this.processName = processName; 
      setDaemon(true);
    }
    public void run()
    { 
      try
      {
        insertString(getLength(),processName+" Started\n",(AttributeSet)null);
        this.err = p.waitFor();
        if(err==0)
          outPanel.insertString(getLength(),processName+" finished\n",(AttributeSet)null);
        else
          outPanel.insertString(getLength(),processName+" interrupted. Exit("+err+")\n",(AttributeSet)null);
      }
      catch(Exception e)
      {
        System.err.println(e.toString());
        e.printStackTrace();
      }          
   }
  } // public class waitProcessEnd 
}