/*
 *
 *   MiniPad - a trivial java editor written in java. 
 *   it helps you to develop java and c programs in the simpliest way possible
 *   providing the minimum set of functions needed and the shortest way to get them
 *   (like a big, clear and coloured button, a menu item and a keybord shortcut).
 *   It acts as a frontend for javac and gcc.
 *
 *   Require JDK 1.2
 *           
 *   Copyright (C) 1999  Andrea Gini
 *
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *   Send questions or suggestions to ginian@lib.disco.unimib.it
 *
 */


/**
   Incapsula il compilatore javac.
   il metodo compile restituisce un processo di sistema che racchiude il processo 
   di compilazione, da cui e' possibile prelevare gli stream di IN OUT ERR o che e' possibile bloccare.
 */
import java.io.*;

public class SunJavac implements MPCompiler {
    
    /**
       Lancia la compilazione del documento con gli opportuni parametri e restituisce un ref al processo di sistema che esegue il task.
       Ogni implementazione deve definire un metodo compile specifico per il tipo di documento accettato
     */
  public Process compile(MPDocument d)
  {
    if(d instanceof JavaDocument)  // prosegue solo se la sottoclasse di MPDocument e' quella giusta
    {
      JavaDocument doc = (JavaDocument)d;
      String commandLine;

      String cp=doc.getFile().getParent();
      String docLocation = doc.getFile().getAbsolutePath();
      commandLine = new String("javac -classpath "+cp+" "+docLocation);
    
      Process c = null;
    
      try
      {
        System.out.println(commandLine);      
        c = Runtime.getRuntime().exec(commandLine);      
      }
      catch(IOException e)
      {
        System.err.println("Can't compile");
        e.printStackTrace();
      }

      return c;
    }
    else
      return null;     
  }
}
